import { VenomConfigContextValue, VenomConfigProps } from "../types";
/**
 * Component for providing Venom configuration values.
 * @param props - The VenomConfigProps object.
 * @returns The VenomConfig component.
 * @example
 * <VenomConfig initVenomConnect={initVenomConnect}>
 *   <App />
 * </VenomConfig>
 */
export declare const VenomConfig: ({ children, initVenomConnect, }: VenomConfigProps) => import("react/jsx-runtime").JSX.Element;
/**
 * Hook for accessing Venom configuration values.
 * @returns The VenomConfigContextValue object.
 * @throws {Error} If the VenomConfigContextValue is not provided.
 * @example
 * const { initVenomConnect } = useVenomConfig();
 * console.log("Venom Connect initialized with:", initVenomConnect);
 */
export declare const useVenomConfig: () => VenomConfigContextValue;
