import { Dispatch, SetStateAction } from "react";
import { VenomConnect } from "venom-connect";
import { ProviderRpcClient } from "everscale-inpage-provider";
import { Account } from "../types";
/**
 * Custom hook for connecting to Venom and managing connection state.
 * @param initVenomConnect - A function that initializes VenomConnect.
 * @param provider - The current provider instance.
 * @param setProvider - A function to set the provider instance.
 * @param setAccount - A function to set the current account.
 * @returns An object containing the login, disconnect, isConnected, and venomConnect functions.
 * @example
 * const { login, disconnect, isConnected, venomConnect } = useVenomConnect(initVenomConnect, provider, setProvider, setAccount);
 * if (isConnected) {
 *   console.log("Connected to Venom!");
 * }
 * login();
 */
export declare const useVenomConnect: (initVenomConnect: () => Promise<VenomConnect>, provider: ProviderRpcClient | null, setProvider: Dispatch<SetStateAction<ProviderRpcClient | null>>, setAccount: Dispatch<SetStateAction<Account | undefined>>) => {
    login: () => Promise<void>;
    disconnect: () => Promise<void>;
    isConnected: boolean;
    venomConnect: VenomConnect | undefined;
};
