import { ContractSubscribeArgs, SubscribeStatus } from "../../types";
/**
 * Custom hook for subscribing to a contract event using the specified subscribeArgs.
 * @param subscribeArgs - The arguments for subscribing to the contract event.
 * @returns An object containing the status of the subscription.
 * @example
 * const subscribeArgs = {
 *   provider: venomProvider,
 *   abi: contractAbi,
 *   eventName: "Transfer",
 *   address: "0x1234567890abcdef",
 *   onDataCallback: (data) => {
 *     console.log("Received event data:", data);
 *   }
 * };
 * const { status } = useContractSubscription(subscribeArgs);
 * console.log(status.isSubscribed); // true if the subscription is active
 */
export declare const useContractSubscription: (subscribeArgs: ContractSubscribeArgs) => {
    status: SubscribeStatus;
};
