import { ReadMessagesArgs, ReadsStatus } from "../../types";
/**
 * Custom hook for reading data from multiple smart contracts.
 * @param readArgs - The arguments for reading the messages.
 * @returns The status of the read operation.
 * @example
 * const readArgs = {
 *   contracts: [
 *     {
 *       address: "0x1234567890abcdef",
 *       abi: contractAbi1,
 *       functionName: "getMessage",
 *       args: []
 *     },
 *     {
 *       address: "0xabcdef1234567890",
 *       abi: contractAbi2,
 *       functionName: "getValue",
 *       args: []
 *     }
 *   ]
 * };
 * const status = useReadMessages(readArgs);
 * console.log(status.data); // Retrieved data from all contracts
 */
export declare const useReadMessages: (readArgs: ReadMessagesArgs) => ReadsStatus;
