import { SendMessageArgs, SendStatus } from "../../types";
/**
 * Custom hook for sending an external message using the specified sendArgs.
 * @param sendArgs - The arguments for sending the external message.
 * @returns An object containing a `run` function to initiate the send operation and the status of the send operation.
 * @example
 * const sendArgs = {
 *   address: "0x1234567890abcdef",
 *   from: "0xabcdef1234567890",
 *   abi: contractAbi,
 *   publicKey: "publicKey",
 *   functionName: "sendMessage",
 *   args: [message],
 *   overrides: {
 *     value: "1000000000",
 *     bounce: true
 *   },
 *   callType: "sendExternal",
 *   executorParams: "executorParams",
 *   withoutSignature: false,
 *   onComplete: (result) => {
 *     console.log("Message sent:", result);
 *   },
 *   onError: (error) => {
 *     console.error("Error sending message:", error);
 *   },
 *   onSettled: (result, error) => {
 *     console.log("Message send operation settled:", result, error);
 *   }
 * };
 * const { run, status } = useSendExternalMessage(sendArgs);
 * run();
 * console.log(status.isSent); // true if the message was sent successfully
 */
export declare const useSendExternalMessage: (sendArgs: SendMessageArgs) => {
    run: () => Promise<void>;
    status: SendStatus;
};
