import { Account } from "../types";
/**
 * Hook for connecting and managing the Venom integration.
 * @returns An object containing connection-related functions and state.
 * @example
 * const { account, login, disconnect, isConnected, venomConnect } = useConnect();
 * if (isConnected) {
 *   console.log("Connected to Venom");
 *   console.log("Current account:", account);
 * }
 * login();
 * disconnect();
 */
export declare const useConnect: () => {
    account: Account | undefined;
    login: () => Promise<void>;
    disconnect: () => Promise<void>;
    isConnected: boolean;
    venomConnect: import("venom-connect/dist/types/VenomConnect").VenomConnect | undefined;
};
