import { SendStatus, SendInternalMessageArgs } from "../types";
/**
 * Hook for sending an internal message.
 * @param args - The arguments for sending the internal message.
 * @returns An object containing the run function and the send status.
 * @example
 * const { run, status } = useSendMessage({
 *   from: "0:x1234567890abcdef",
 *   to: "0:xabcdef1234567890",
 *   amount: "100",
 *   onComplete: (result) => {
 *     console.log("Message sent successfully:", result);
 *   },
 *   onError: (error) => {
 *     console.error("Error occurred while sending the message:", error);
 *   },
 *   onSettled: (result, error) => {
 *     if (error) {
 *       console.log("Message settled with an error:", error);
 *     } else {
 *       console.log("Message settled successfully:", result);
 *     }
 *   },
 *   overrides?: {
 *     bounce?: false,
 *   },
 * });
 */
export declare const useSendMessage: (args: SendInternalMessageArgs) => {
    run: () => Promise<void>;
    status: SendStatus;
};
