import { SignStatus, SignMessageArgs } from "../types";
/**
 * Hook for signing a message.
 * @param signArgs - The arguments for signing the message.
 * @returns An object containing the sign function and the  `SignStatus`.
 * @example
 * const { sign, status } = useSignMessage({
 *   publicKey: "0xabcdef1234567890",
 *   data: "Hello, Venom!",
 *   onComplete: (result) => {
 *     console.log("Message signed successfully:", result);
 *   },
 *   onError: (error) => {
 *     console.error("Error occurred while signing the message:", error);
 *   },
 *   onSettled: (result, error) => {
 *     if (error) {
 *       console.log("Message signing settled with an error:", error);
 *     } else {
 *       console.log("Message signing settled successfully:", result);
 *     }
 *   },
 * });
 **/
export declare const useSignMessage: (signArgs: SignMessageArgs) => {
    sign: () => Promise<void>;
    status: SignStatus;
};
